<?php

namespace App\Livewire\Admin\Settings\System;

use App\Settings\CronJobSettings as CronSettings;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Artisan;
use Livewire\Component;
use Symfony\Component\Process\PhpExecutableFinder;

class CronJobSettings extends Component
{
    public ?string $last_cron_run = '';

    public ?string $last_cron_run_datetime = '';

    public function mount()
    {
        if (! checkPermission('system_settings.view')) {
            $this->notify(['type' => 'danger', 'message' => t('access_denied_note')], true);

            return redirect(route('admin.dashboard'));
        }
        $settings    = app(CronSettings::class);
        $lastCronRun = $settings->last_cron_run;

        if ($lastCronRun && $lastCronRun !== 'false') {
            $timestamp = is_numeric($lastCronRun) ? intval($lastCronRun) : json_decode($lastCronRun);
            if ($timestamp) {
                $this->last_cron_run          = Carbon::createFromTimestamp($timestamp)->diffForHumans();
                $this->last_cron_run_datetime = Carbon::createFromTimestamp($timestamp)->format('Y-m-d H:i:s');
            } else {
                $this->last_cron_run = t('never');
            }
        } else {
            $this->last_cron_run = t('never');
        }
    }

    public function getPrepareCronUrlProperty()
    {
        return sprintf(
            '* * * * * %s %s/artisan schedule:run >> /dev/null 2>&1',
            (new PhpExecutableFinder)->find(false),
            base_path()
        );
    }

    public function save() {}

    public function runCronManually()
    {
        try {
            Artisan::call('schedule:run');

            $now                     = now();
            $settings                = app(CronSettings::class);
            $settings->last_cron_run = $now->timestamp;
            $settings->save();

            $this->last_cron_run          = $now->diffForHumans();
            $this->last_cron_run_datetime = $now->format('Y-m-d H:i:s');

            $this->notify([
                'type'    => 'success',
                'message' => t('Cron job executed successfully'),
            ]);

        } catch (\Exception $e) {
            $this->notify([
                'type'    => 'danger',
                'message' => t('failed_to_execute_cron_job') . $e->getMessage(),
            ]);
        }
    }

    public function isCronStale(): bool
    {
        $settings = app(CronSettings::class);
        $lastRun  = $settings->last_cron_run;

        if (! $lastRun || $lastRun === 'false') {
            return true;
        }

        $timestamp = json_decode($lastRun);

        return Carbon::createFromTimestamp($timestamp)->diffInHours(now()) >= 48;
    }

    public function render()
    {
        return view('livewire.admin.settings.system.cron-job-settings');
    }
}
