<?php

namespace App\Providers;

use Illuminate\Console\Scheduling\Schedule;
use Illuminate\Support\ServiceProvider;

class SchedulingServiceProvider extends ServiceProvider
{
    /**
     * Register services.
     */
    public function register(): void
    {
        $this->app->booted(function () {

            $schedule = $this->app->make(Schedule::class);
            $timezone = get_setting('general.timezone', config('app.timezone'));

            // Run chat history cleanup daily at midnight
            $schedule->command('whatsapp:clear-chat-history')
                ->daily()
                ->timezone($timezone)
                ->before(function () {
                    set_setting('cron-job.last_cron_run', now()->timestamp);
                });

            // Run every minute to check for campaigns that need to be sent
            $schedule->command('campaigns:process-scheduled')
                ->everyMinute()
                ->timezone($timezone)
                ->before(function () {
                    set_setting('cron-job.last_cron_run', now()->timestamp);
                });

            $schedule->command('queue:work --queue=whatsapp-messages --sleep=3 --tries=3 --timeout=60 --backoff=5 --max-time=3600 --max-jobs=100')
                ->withoutOverlapping()
                ->everyMinute();
        });
    }

    /**
     * Bootstrap services.
     */
    public function boot(): void
    {
        //
    }
}
