<div x-cloak>
    <div class="max-w-3xl mx-auto px-4 sm:px-6 md:px-8">
        <x-page-heading>
            {{ t('account_profile') }}
        </x-page-heading>
    </div>
    <div class="mt-6 max-w-3xl mx-auto px-4 sm:px-6 lg:px-8">
        <x-card class="relative rounded-lg overflow-hidden">
            <x-slot:content>
                <form wire:submit.prevent="save" class="mt-3">
                    <div x-data="{ activeTab: 'profile' }">
                        <div class="border-b border-gray-200 dark:border-gray-600">
                            <nav class="-mb-px flex space-x-8" aria-label="Tabs">
                                <button type="button" x-on:click="activeTab = 'profile'"
                                    class="whitespace-nowrap py-4 px-1 font-medium text-sm transition duration-300"
                                    :class="{
                                        'border-b-2 border-indigo-500 text-indigo-600': activeTab === 'profile',
                                        'border-b-2 border-red-500  dark:border-red-500 text-red-600 dark:text-red-500': activeTab !== 'profile' &&
                                            {{ $errors->hasAny(['profile_image_url', 'firstname', 'lastname', 'email', 'phone', 'default_language']) ? 'true' : 'false' }},
                                        'dark:text-slate-200': activeTab !== 'profile' &&
                                            !
                                            {{ $errors->hasAny(['profile_image_url', 'firstname', 'lastname', 'email', 'phone', 'default_language']) ? 'true' : 'false' }}
                                    }">
                                    {{ t('profile') }}
                                </button>
                                <button type="button" x-on:click="activeTab = 'password'"
                                    class="whitespace-nowrap py-4 px-1 font-medium text-sm transition duration-300"
                                    :class="{
                                        'border-b-2 border-indigo-500 text-indigo-600': activeTab === 'password',
                                        'border-b-2 border-red-500 dark:border-red-500 text-red-500 dark:text-red-500': activeTab !== 'password' &&
                                            {{ $errors->hasAny(['current_password', 'password', 'password_confirmation']) ? 'true' : 'false' }},
                                        'dark:text-slate-200': activeTab !== 'password' &&
                                            !
                                            {{ $errors->hasAny(['current_password', 'password', 'password_confirmation']) ? 'true' : 'false' }}
                                    }">
                                    {{ t('password') }}
                                </button>
                            </nav>
                        </div>

                        <!-- Profile Section -->
                        <div x-show="activeTab === 'profile'">
                            <!-- Profile Image Section -->
                            <div class="w-full mt-6">
                                <div x-data="{
                                    photoName: null,
                                    photoPreview: null,
                                    maxSizeMB: 5,
                                    allowedTypes: ['jpeg', 'png'],
                                    errorMessage: '',
                                    validateFile(event) {
                                        this.errorMessage = ''; // Clear previous errors
                                        let file = event.target.files[0];
                                
                                        if (!file) return;
                                
                                        // Check file extension
                                        let fileExtension = file.name.split('.').pop().toLowerCase();
                                        if (!this.allowedTypes.includes(fileExtension)) {
                                            this.errorMessage = `Invalid file type. Allowed: ${this.allowedTypes.join(', ')}`;
                                            event.target.value = ''; // Clear the input
                                            return;
                                        }
                                
                                        // Check file size (5MB = 5 * 1024 * 1024 bytes)
                                        const maxSizeBytes = this.maxSizeMB * 1024 * 1024;
                                        if (file.size > maxSizeBytes) {
                                            this.errorMessage = `File size exceeds ${this.maxSizeMB}MB limit`;
                                            event.target.value = ''; // Clear the input
                                            return;
                                        }
                                
                                        this.photoName = file.name;
                                        const reader = new FileReader();
                                        reader.onload = (e) => this.photoPreview = e.target.result;
                                        reader.readAsDataURL(file);
                                    }
                                }">
                                    <x-label class="mt-[2px]" for="profile_image_url" :value="t('profile_image')" />
                                    <p class="text-xs text-gray-500 mt-1">{{ t('allowed_fromats_jpeg_png_max_5') }} </p>
                                    <div class="flex items-center gap-8 mt-1">
                                        <div x-show="!photoPreview">
                                            <img src="{{ file_exists(public_path('storage/' . $user->profile_image_url)) && $user->profile_image_url ? asset('storage/' . $user->profile_image_url) : asset('img/user-placeholder.jpg') }}"
                                                alt="{{ $user->first_name }} {{ $user->last_name }}"
                                                class="h-12 w-12 rounded-full object-cover">
                                        </div>
                                        <div x-cloak x-show="photoPreview">
                                            <span class="block h-12 w-12 rounded-full bg-cover bg-center"
                                                x-bind:style="'background-image: url(' + photoPreview + ');'"></span>
                                        </div>
                                        <div>
                                            <input wire:model="profile_image_url" x-ref="photo"
                                                x-on:change="validateFile($event)" type="file" class="hidden"
                                                accept=".jpg,.jpeg,.png" />
                                            <x-button.secondary
                                                x-on:click="$refs.photo.click();">{{ t('change') }}</x-button.secondary>
                                            @if (file_exists(public_path('storage/' . $user->profile_image_url)) && $user->profile_image_url)
                                                <x-button.text wire:click="removeProfileImage"
                                                    class="ml-3">{{ t('remove_img') }}</x-button.text>
                                            @endif
                                        </div>
                                    </div>
                                    <!-- Error Message -->
                                    <p x-show="errorMessage" class="text-red-500 text-sm mt-1" x-text="errorMessage">
                                    </p>
                                    <x-input-error class="mt-1" for="profile_image_url" />
                                </div>
                            </div>
                            <div class="grid grid-cols-1 gap-4 sm:grid-cols-2 mt-4">
                                <div>
                                    <div class="flex items-center gap-1">
                                        <span class="text-red-500">*</span>
                                        <x-label for="firstname" :value="t('firstname')" />
                                    </div>
                                    <x-input type="text" wire:model.defer="firstname" class="mt-1 block w-full" />
                                    <x-input-error for="firstname" class="mt-2" />
                                </div>
                                <div>
                                    <div class="flex items-center gap-1">
                                        <span class="text-red-500">*</span>
                                        <x-label for="lastname" :value="t('lastname')" />
                                    </div>
                                    <x-input type="text" wire:model.defer="lastname" class="mt-1 block w-full" />
                                    <x-input-error for="lastname" class="mt-2" />
                                </div>
                            </div>
                            <div class="grid grid-cols-1 gap-4 sm:grid-cols-2 mt-4">
                                <div>
                                    <div class="flex items-center gap-1">
                                        <span class="text-red-500">*</span>
                                        <x-label for="email" :value="t('email')" />
                                    </div>
                                    <x-input type="text" wire:model.defer="email" class="mt-1 block w-full" />
                                    <x-input-error for="email" class="mt-2" />
                                </div>
                                <div class="mt-1">
                                    <div class="flex items-center gap-1">
                                        <span class="text-red-500">*</span>
                                        <x-label for="phoneNumberInput" :value="t('phone')" />
                                    </div>
                                    <div wire:ignore>
                                        <x-input class="phone-input mt-1" x-ref="phone" id="phone" type="tel"
                                            wire:model.defer="phone" />
                                    </div>
                                    <x-input-error for="phone" class="mt-2" />
                                </div>
                            </div>
                            <div class="pb-4 mt-4" wire:ignore>
                                <x-label for="default_language" :value="t('default_language')" />
                                <x-select wire:model.defer="default_language" id="default_language"
                                    class="block w-full mt-1 tom-select">
                                    <option value="">{{ t('select_language') }}</option>
                                    @foreach (getLanguage(null, ['code', 'name']) as $language)
                                        <option value="{{ $language->code }}"> {{ $language->name }}</option>
                                    @endforeach
                                </x-select>
                            </div>
                        </div>

                        <!-- Password Section -->
                        <div x-show="activeTab === 'password'">
                            <div class="mt-4">
                                <div class="flex items-center gap-1">
                                    <span class="text-red-500">*</span>
                                    <x-label for="current_password" :value="t('current_password')" />
                                </div>
                                <x-input id="current_password" wire:model.defer="current_password" type="password"
                                    class="mt-1 block w-full" />
                                <x-input-error for="current_password" class="mt-2" />
                            </div>
                            <div class="mt-4">
                                <div class="flex items-center gap-1">
                                    <span class="text-red-500">*</span>
                                    <x-label for="password" :value="t('new_password')" />
                                </div>
                                <x-input id="password" wire:model.defer="password" type="password"
                                    class="mt-1 block w-full" />
                                <x-input-error for="password" class="mt-2" />
                            </div>
                            <div class="mt-4 pb-4">
                                <div class="flex items-center gap-1">
                                    <span class="text-red-500">*</span>
                                    <x-label for="password_confirmation" :value="t('confirm_password')" />
                                </div>
                                <x-input id="password_confirmation" wire:model.defer="password_confirmation"
                                    type="password" class="mt-1 block w-full" />
                                <x-input-error for="password_confirmation" class="mt-2" />
                            </div>
                        </div>
                    </div>
            </x-slot:content>
            <!-- Submit Button -->
            <x-slot:footer class="bg-slate-50 dark:bg-transparent">
                <div class="flex justify-end">
                    <x-button.loading-button type="submit" target="save">
                        {{ t('save') }}
                    </x-button.loading-button>
                </div>
            </x-slot:footer>
            </form>
        </x-card>
    </div>
</div>
